@@ -1,6 +1,6 @@
 package HTML::Shakan;
 use Any::Moose;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 use Carp ();
 
 use FormValidator::Lite 'Email', 'URL', 'Date', 'File';
@@ -397,13 +397,13 @@ If you want to know about shakan, please see L<http://www.konuma-sakan.com/index
 
 =over 4
 
-=item $shakan->render();
+=item my $html = $shakan->render(); :Str
 
-render form.
+Render form.
 
-=item $shakan->render_field($name);
+=item $shakan->render_field($name); :Str
 
-render partial form named $name.
+Render partial form named C<<$name>>.
 
 =back
 
